@@ -1,4 +1,4 @@
-// $Id: AliasGE.h,v 1.6 1998/03/25 12:42:12 zeller Exp $ -*- C++ -*-
+// $Id: AliasGE.h,v 1.7 1998/07/31 17:12:41 zeller Exp $ -*- C++ -*-
 // AliasGraphEdge class: temporary edge from or to alias node
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
@@ -51,8 +51,9 @@ protected:
 
 public:
     // Constructor
-    AliasGraphEdge(int disp_nr, GraphNode *from, GraphNode *to)
-	: ArcGraphEdge(from, to),
+    AliasGraphEdge(int disp_nr, GraphNode *from, GraphNode *to, 
+		   EdgeAnnotation *ann = 0)
+	: ArcGraphEdge(from, to, ann),
 	  _disp_nr(disp_nr)
     {}
 
