@@ -1,7 +1,7 @@
-// $Id: AsyncAgent.h,v 1.17 1998/03/25 12:42:19 zeller Exp $
+// $Id: AsyncAgent.h,v 1.21 1998/10/01 19:12:57 zeller Exp $
 // Asynchron Agent Interface
 
-// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Copyright (C) 1995-1998 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
 // This file is part of DDD.
@@ -59,8 +59,15 @@
 #include <X11/Intrinsic.h>
 #include "Agent.h"
 
-class AsyncAgent;
+// Set to 1 if you want asynchronous notification
+// #define ASYNC_CHILD_STATUS_CHANGE
 
+#ifndef ASYNC_CHILD_STATUS_CHANGE
+#define ASYNC_CHILD_STATUS_CHANGE (XtSpecificationRelease >= 6)
+#endif // !defined(ASYNC_CHILD_STATUS_CHANGE)
+
+
+class AsyncAgent;
 
 typedef void (*AsyncAgentHandler)(AsyncAgent *agent);
 
@@ -143,6 +150,15 @@ private:
 
     // used in childStatusChange()
     int new_status;
+    bool status_change_pending;
+
+#if ASYNC_CHILD_STATUS_CHANGE
+    XtSignalId signal_id;
+#else
+    XtIntervalId signal_id;		// Just for padding
+#endif
+
+    bool killing_asynchronously;
 
     void initHandlers();
     void addDeathOfChildHandler();
@@ -151,10 +167,16 @@ private:
     void deleteWorkProc(AsyncAgentWorkProcInfo *info, bool remove = true);
     void deleteAllWorkProcs();
 
+    // Call when NEW_STATUS has been set
+    void statusChange();
+
+#if ASYNC_CHILD_STATUS_CHANGE
+    static void _childStatusChange(XtPointer client_data, XtSignalId *id);
+#endif
+
     // X Event Handlers
     static void somethingHappened(XtPointer client_data,
 				  int *fid, XtInputId *id);
-    static void _childStatusChange(XtPointer client_data, XtIntervalId *iid);
     static void childStatusChange(Agent *agent, void *client_data,
 				  void *call_data);
     static Boolean callTheHandlers(XtPointer client_data);
@@ -216,10 +238,11 @@ public:
     XtAppContext appContext() const { return _appContext; }
 
     // Constructors
-    AsyncAgent(XtAppContext app_context, string pth, 
+    AsyncAgent(XtAppContext app_context, const string& pth, 
 	       unsigned nTypes = AsyncAgent_NTypes):
 	Agent(pth, nTypes), _appContext(app_context), workProcs(0), 
-	new_status(0)
+	new_status(0), status_change_pending(false), 
+	signal_id(0), killing_asynchronously(false)
     {
 	initHandlers();
 	addDeathOfChildHandler();
@@ -228,7 +251,8 @@ public:
     AsyncAgent(XtAppContext app_context, FILE *in = stdin, FILE *out = stdout,
 	FILE *err = 0, unsigned nTypes = AsyncAgent_NTypes):
 	Agent(in, out, err, nTypes), _appContext(app_context), workProcs(0),
-	new_status(0)
+	new_status(0), status_change_pending(false),
+	signal_id(0), killing_asynchronously(false)
     {
 	initHandlers();
     }
@@ -236,14 +260,17 @@ public:
     AsyncAgent(XtAppContext app_context, bool dummy,
 	unsigned nTypes = AsyncAgent_NTypes):
 	Agent(dummy, nTypes), _appContext(app_context), workProcs(0),
-	new_status(0)
+	new_status(0), status_change_pending(false),
+	signal_id(0), killing_asynchronously(false)
     {
 	initHandlers();
     }
 
     // Duplicator
     AsyncAgent(const AsyncAgent& c):
-	Agent(c), _appContext(c.appContext()), workProcs(0), new_status(0)
+	Agent(c), _appContext(c.appContext()), workProcs(0), 
+	new_status(0), status_change_pending(false),
+	signal_id(0), killing_asynchronously(false)
     {
 	initHandlers();
     }
@@ -259,6 +286,9 @@ public:
 	clearHandlers();
     }
 
+    // Commit pending status changes
+    virtual void commit();
+
     // These need special management:
     virtual void abort();
     virtual void terminate(bool onExit = false);
