@@ -1,4 +1,4 @@
-// $Id: BoxGraphN.h,v 1.12 1998/03/25 12:42:26 zeller Exp $
+// $Id: BoxGraphN.h,v 1.14 1998/09/21 20:22:57 zeller Exp $
 // BoxGraphNode class: RegionGraphNode with box
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -66,10 +66,16 @@ protected:
 public:
     // Constructor
     BoxGraphNode(Box *b, const BoxPoint& initialPos = BoxPoint(), 
-		 MarkBox *h = 0):
-	RegionGraphNode(initialPos, b->size()),
-	_box(b->link()),
-        _highlight(h)
+		 MarkBox *h = 0)
+	: RegionGraphNode(initialPos, b->size()),
+	  _box(b->link()),
+	  _highlight(h)
+    {}
+
+    BoxGraphNode()
+	: RegionGraphNode(),
+	  _box(0),
+	  _highlight(0)
     {}
 
     GraphNode *dup() const
@@ -80,9 +86,8 @@ public:
     // Destructor
     virtual ~BoxGraphNode()
     {
-	if (_highlight)
-	    _highlight->unlink();
-	_box->unlink();
+	if (_box)
+	    _box->unlink();
     }
 
     // Attributes
@@ -107,16 +112,7 @@ public:
     }
 
     // Set the box.
-    void setBox(Box *b)
-    {
-	setHighlight(0);
-
-	Box *old = _box;
-	_box = b->link();
-	old->unlink();
-	resize(b->size());
-    }
-
+    void setBox(Box *b);
 
     // Print
     virtual void _print(ostream& os, const GraphGC& gc) const;
