@@ -1,4 +1,4 @@
-// $Id: BreakPoint.h,v 1.33 1998/11/24 09:54:41 zeller Exp $
+// $Id: BreakPoint.h,v 1.33.4.1 1998/12/04 10:39:03 zeller Exp $
 // Breakpoint handler
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -131,11 +131,11 @@ protected:
 
 public:
     // Create new breakpoint from INFO_OUTPUT.  ARG denotes the
-    // argument of a breakpoint setting command.  If NUMBER is given,
-    // assign this number.  If FILE is given, assume this file.
+    // argument of a breakpoint setting command.  If NUMBER is != 0,
+    // assign this number.  If FILE is != "", assume this file.
     // Delete own info from INFO_OUTPUT.
-    BreakPoint (string& info_output, char *arg = "",
-		int number = 0, char *file = "");
+    BreakPoint(string& info_output, 
+	       const string& arg, int number, string& file);
 
     // This should avoid link warnings on SGI
     // as reported by Mike Tosti <tosti@cinesite.com>
