@@ -1,4 +1,4 @@
-// $Id: GDBAgent.h,v 1.93 1998/06/14 12:38:47 zeller Exp $
+// $Id: GDBAgent.h,v 1.107 1998/10/24 00:10:47 zeller Exp $
 // Communicate with separate GDB process
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -58,7 +58,7 @@
 // Debugger types
 //-----------------------------------------------------------------------------
 
-enum DebuggerType { GDB, DBX, XDB, JDB };
+enum DebuggerType { GDB, DBX, XDB, JDB, PYDB, PERL };
 
 
 //-----------------------------------------------------------------------------
@@ -76,6 +76,8 @@ enum ProgramLanguage {
     LANGUAGE_ADA,		// Ada (GNAT), as supported by GDB
     LANGUAGE_CHILL,		// Chill, as supported by GDB.
     LANGUAGE_FORTRAN,		// FORTRAN, as supported by GDB.
+    LANGUAGE_PYTHON,		// Python, as supported by PYDB.
+    LANGUAGE_PERL,		// Perl, as supported by Perl.
     LANGUAGE_OTHER		// Others
 };
 
@@ -113,8 +115,6 @@ typedef void (* OQACProc) (const StringArray& complete_answers,
 			   void *user_data);
 
 //-----------------------------------------------------------------------------
-// Determine debugger type
-DebuggerType debugger_type(const string& type);
 
 // Create appropriate call for the given debugger
 string build_gdb_call(DebuggerType debugger_type,
@@ -188,6 +188,9 @@ private:
     bool _has_err_redirection;
     bool _has_givenfile_command;
     bool _has_cont_sig_command;
+    bool _has_examine_command;
+    bool _has_rerun_command;
+    bool _rerun_clears_args;
 
     ProgramLanguage _program_language; // Current program language
 
@@ -211,6 +214,10 @@ protected:
     // General trace function
     void trace(char *prefix, void *call_data) const;
 
+    // Perl specials
+    static void munch_perl_array(string& value, bool hash);
+    static void munch_perl_scalar(string& value);
+
 public:
     // Constructor
     GDBAgent (XtAppContext app_context,
@@ -384,6 +391,18 @@ public:
     bool has_cont_sig_command() const   { return _has_cont_sig_command; }
     bool has_cont_sig_command(bool val) { return _has_cont_sig_command = val; }
 
+    // True if debugger has `examine' or `x' command
+    bool has_examine_command() const   { return _has_examine_command; }
+    bool has_examine_command(bool val) { return _has_examine_command = val; }
+
+    // True if debugger has `rerun' command
+    bool has_rerun_command() const   { return _has_rerun_command; }
+    bool has_rerun_command(bool val) { return _has_rerun_command = val; }
+
+    // True if `rerun' command clears current arguments
+    bool rerun_clears_args() const   { return _rerun_clears_args; }
+    bool rerun_clears_args(bool val) { return _rerun_clears_args = val; }
+
     // Current program language
     ProgramLanguage program_language() const   { return _program_language; }
     ProgramLanguage program_language(ProgramLanguage val) 
@@ -400,7 +419,8 @@ public:
     // True if debugger can enable breakpoints
     bool has_enable_command() const
     { 
-	return type() == GDB || type() == XDB || has_handler_command();
+	return type() == GDB || type() == XDB || type() == PYDB || 
+	    has_handler_command();
     }
     bool has_disable_command() const
     {
@@ -410,26 +430,29 @@ public:
     // True if debugger can set ignore counts on breakpoints
     bool has_ignore_command() const
     {
-	return type() == GDB || type() == XDB || has_handler_command();
+	return type() == GDB || type() == XDB || type() == PYDB || 
+	    has_handler_command();
     }
 
     // True if debugger can set conditions on breakpoints
     bool has_condition_command() const
     {
-	return type() == GDB;
+	return type() == GDB || type() == PYDB;
     }
 
     // True if debugger can delete breakpoints by number
     bool has_delete_command() const
     {
-	return type() == GDB || type() == XDB || type() == DBX;
+	return type() == GDB || type() == XDB || 
+	    type() == DBX || type() == PYDB;
     }
 
     // True if debugger has volatile breakpoints (i.e. breakpoints may
     // change at any time)
     bool has_volatile_breakpoints() const
     {
-	return type() == GDB || type() == XDB || type() == DBX;
+	return type() == GDB || type() == XDB || 
+	    type() == DBX || type() == PYDB || type() == PERL;
     }
 
     // True if debugger supports I/O redirection
@@ -438,16 +461,18 @@ public:
 	return type() == GDB || type() == XDB || type() == DBX;
     }
 
-    // True if debugger supports assignments redirection
+    // True if debugger supports assignments
     bool has_assign_command() const
     {
-	return type() == GDB || type() == XDB || type() == DBX;
+	return type() == GDB || type() == XDB || type() == DBX || 
+	    type() == PYDB || type() == PERL;
     }
 
     // True if debugger supports calling system functions
     bool has_system_calls() const
     {
-	return type() == GDB || type() == XDB || type() == DBX;
+	return type() == GDB || type() == XDB || type() == DBX || 
+	    type() == PERL;
     }
 
     // True if debugger supports loading and examining executables
@@ -477,25 +502,36 @@ public:
     // True if debugger supports `cd'
     bool has_cd_command() const
     {
-	return type() == GDB || type() == XDB || type() == DBX;
+	return type() == GDB || type() == XDB || 
+	    type() == DBX || type() == PYDB || type() == PERL;
     }
 
     // True if debugger supports `shell'
     bool has_shell_command() const
     {
-	return type() == GDB || type() == XDB || type() == DBX;
+	return type() == GDB || type() == XDB || type() == DBX || 
+	    type() == PERL;
+    }
+
+    // True if debugger has numbered breakpoints
+    bool has_numbered_breakpoints()
+    {
+	return type() == GDB || type() == DBX || type() == XDB || 
+	    type() == PYDB;
     }
 
     // True if debugger supports temporary breakpoints
     bool has_temporary_breakpoints() const
     {
-	return type() == GDB || type() == XDB || has_when_command();
+	return type() == GDB || type() == XDB || type() == PYDB || 
+	    has_when_command();
     }
 
     // True if debugger supports breakpoint conditions
     bool has_breakpoint_conditions() const
     {
-	return type() == GDB || type() == XDB || type() == DBX;
+	return type() == GDB || type() == XDB || 
+	    type() == DBX || type() == PYDB || type() == PERL;
     }
 
     // True if debugger has typed pointers, as in `(TYPE)0x0'
@@ -525,13 +561,13 @@ public:
     // True if `display X' automatically prints X
     bool display_prints_values() const
     {
-	return type() == GDB;
+	return type() == GDB || type() == PYDB;
     }
 
     // True if debugger can enable displays
     bool has_enable_display_command() const
     {
-	return type() == GDB;
+	return type() == GDB || type() == PYDB;
     }
     bool has_disable_display_command() const
     {
@@ -541,7 +577,7 @@ public:
     // True if debugger has numbered displays
     bool has_numbered_displays()
     {
-	return type() == GDB;
+	return type() == GDB || type() == PYDB;
     }
 
     // True if debugger wants displays separated by `,'
@@ -580,6 +616,14 @@ public:
 	return has_enable_command() || has_conditions();
     }
 
+    // True if a minimum indent is required.  This is true for
+    // scripting languages.
+    bool requires_script_indent() const
+    {
+	return program_language() == LANGUAGE_PERL ||
+	    program_language() == LANGUAGE_PYTHON;
+    }
+
     // True if DBX output is to be processed verbatim
     bool verbatim() const        { return _verbatim; }
     bool verbatim(bool val)      { return _verbatim = val; }
@@ -592,49 +636,67 @@ public:
     bool detect_echos() const        { return _detect_echos; }
     bool detect_echos(bool val)      { return _detect_echos = val; }
 
-    // GDB: "print EXPR".  If INTERNAL is set, avoid side effects
-    // (such as setting the value history in GDB).
-    string print_command(string expr = "", bool internal = true) const; 
-    // GDB: "set variable VAR = EXPR"
-    string assign_command(string var, string expr) const;
+    // Several commands
+				                    // GDB command
+						    // -----------------------
+    string print_command(string expr = "",          // print|output EXP
+			 bool internal = true) const;
+    string assign_command(string var,               // set variable VAR = EXPR
+			  string expr) const;
+    string display_command(string expr = "") const; // display EXPR
+    string where_command(int count = 0) const;	    // where COUNT
+    string pwd_command() const;	                    // pwd
+    string frame_command(int number) const;         // frame NUMBER
+    string relative_frame_command(int offset) const;// up|down OFFSET
+    string frame_command() const;                   // frame
+    string func_command() const;                    // func
+    string echo_command(string text) const;         // echo TEXT
+    string whatis_command(string expr) const;       // whatis EXPR
+    string dereferenced_expr(string expr) const;    // *EXPR
+    string address_expr(string expr) const;         // &EXPR
+    string index_expr(string expr, string index) const; // EXPR[INDEX]
+    int default_index_base() const;                 // 0 in C, else 1
+    string member_separator() const;                // " = " in C
 
-    string display_command(string expr = "") const; // GDB: "display EXPR"
-    string where_command(int count = 0) const;	    // GDB: "where COUNT"
-    string pwd_command() const;	                    // GDB: "pwd "
-    string frame_command(int number) const;         // GDB: "frame NUMBER"
-    string frame_command() const;                   // GDB: "frame"
-    string func_command() const;                    // DBX: "func"
-    string echo_command(string text) const;         // GDB: "echo TEXT"
-    string whatis_command(string expr) const;       // GDB: "whatis EXPR"
-    string dereferenced_expr(string expr) const;    // GDB: "*EXPR"
-    string address_expr(string expr) const;         // GDB: "&EXPR"
-    string index_expr(string expr, string index) const; // GDB: "EXPR[INDEX]"
-    int default_index_base() const;                 // GDB: 0 in C, else 1
-    string info_locals_command() const;	            // GDB: "info locals"
-    string info_args_command() const;	            // GDB: "info args"
-    string info_display_command() const;	    // GDB: "info display"
+    string info_locals_command() const;	            // info locals
+    string info_args_command() const;	            // info args
+    string info_display_command() const;	    // info display
     string disassemble_command(string start, string end = "") const;
-                                                // GDB: "disassemble START END"
-    string make_command(string target) const;       // GDB: "make TARGET"
-    string jump_command(string pc) const;           // GDB: "jump PC"
-    string regs_command(bool all = true) const;	    // GDB: "info registers"
+                                                    // disassemble START END
+    string make_command(string target) const;       // make TARGET
+    string jump_command(string pc) const;           // jump PC
+    string regs_command(bool all = true) const;	    // info registers
     string watch_command(string expr, WatchMode w = WATCH_CHANGE) const;
-				                    // GDB: "watch EXPR"
-    string kill_command() const;                    // GDB: "kill"
-    string enable_command(string bp = "") const;    // GDB: "enable BP"
-    string disable_command(string bp = "") const;   // GDB: "disable BP"
-    string delete_command(string bp = "") const;    // GDB: "delete BP"
+				                    // watch EXPR
+    string kill_command() const;                    // kill
+    string enable_command(string bp = "") const;    // enable BP
+    string disable_command(string bp = "") const;   // disable BP
+    string delete_command(string bp = "") const;    // delete BP
     string ignore_command(string bp, int count) const; 
-                                                    // GDB: "ignore BP COUNT"
+                                                    // ignore BP COUNT
     string condition_command(string bp, string expr) const; 
-				                    // GDB: "cond BP EXPR"
-    string shell_command(string cmd) const;	    // GDB: "shell CMD"
-    string debug_command(string program = "") const; // GDB: "file PROGRAM"
-    string signal_command(int sig) const;           // GDB: "signal SIG"
-    string nop_command(string comment = "") const;  // GDB: "# comment"
+				                    // cond BP EXPR
+    string shell_command(string cmd) const;	    // shell CMD
+    string debug_command(string file = "",          // file FILE
+			 string args = "") const;
+    string signal_command(int sig) const;           // signal SIG
+    string nop_command(string comment = "") const;  // # comment
+
+    // Bring VALUE of VAR into a form understood by DDD
+    void munch_value(string& value, const string& var) const;
+
+    // Split a Perl variable into its components
+    static void split_perl_var(const string& var,
+			       string& prefix, string& package, string& name);
+
+    // Run program with given arguments
+    string run_command(string args) const;	    // set args ARGS\nrun
+
+    // Run program, re-using current arguments
+    string rerun_command() const;                   // run
 
     // Default history file
-    string history_file() const;                    // GDB: "~/.gdb_history"
+    string history_file() const;                    // GDB: ~/.gdb_history
 
     // Send DATA to process
     virtual int write(const char *data, int length)
