@@ -1,4 +1,4 @@
-// $Id: SourceView.h,v 1.130 1998/06/14 14:54:39 zeller Exp $
+// $Id: SourceView.h,v 1.143 1998/10/25 21:58:21 zeller Exp $
 // View the Source.
 
 // Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
@@ -79,12 +79,9 @@ struct BreakpointPropertiesInfo;
 
 //-----------------------------------------------------------------------------
 class SourceView {
-    static void add_to_history(const string& file_name, int line);
-    static void add_to_history(const string& address);
-    static void add_current_to_history();
-
-    static void goto_entry(string entry);
-
+    //-----------------------------------------------------------------------
+    // Callbacks
+    //-----------------------------------------------------------------------
     static void set_source_argCB         (Widget, XtPointer, XtPointer);
 
     static void line_popup_setCB         (Widget, XtPointer, XtPointer);
@@ -151,19 +148,25 @@ class SourceView {
     static void ThreadCommandCB  (Widget, XtPointer, XtPointer);
 
     static void SetWatchModeCB(Widget, XtPointer, XtPointer);
-
-    static void update_title ();
     static void ActivateGlyphCB(Widget, XtPointer, XtPointer);
-    static int line_height (Widget text_w);
 
+    // Set shell title
+    static void update_title();
+
+    // Return height of a text line
+    static int line_height(Widget text_w);
+
+    // Create text or code widget
     static void create_text(Widget parent,
 			    const string& base, bool editable,
 			    Widget& form, Widget& text);
 
-    static void refresh_bp_disp ();
-    static void refresh_source_bp_disp ();
-    static void refresh_code_bp_disp ();
+    // Refresh displays
+    static void refresh_bp_disp();
+    static void refresh_source_bp_disp();
+    static void refresh_code_bp_disp();
 
+    // Clear breakpoint helpers
     static void clearBP(void *client_data, XtIntervalId *timer);
     static void clearJumpBP(const string& answer, void *client_data);
 
@@ -175,6 +178,11 @@ class SourceView {
 	return move_bp(nr, address, origin, true);
     }
 
+    // Position history
+    static void add_current_to_history();
+    static void add_position_to_history(const string& file_name, 
+					int line, bool stopped);
+
     // Set condition of breakpoints NRS to COND.
     // * If COND is char(-1), preserve old condition.
     // * If MAKE_FALSE is >= 0, disable breakpoint by making 
@@ -239,6 +247,7 @@ class SourceView {
     static void dropGlyphAct      (Widget, XEvent*, String*, Cardinal*);
     static void deleteGlyphAct    (Widget, XEvent*, String*, Cardinal*);
     static void doubleClickAct    (Widget, XEvent*, String*, Cardinal*);
+    static void setArgAct         (Widget, XEvent*, String*, Cardinal*);
 
     //-----------------------------------------------------------------------
     // Timer procedures
@@ -265,10 +274,6 @@ class SourceView {
     //-----------------------------------------------------------------------
     // Data
     //-----------------------------------------------------------------------
-    static StringArray history;
-    static int history_position; // Last position in history + 1
-    static bool source_history_locked;
-    static bool code_history_locked;
     static bool checking_scroll;
 
     static Widget toplevel_w;	 // Top-level widget
@@ -396,7 +401,8 @@ class SourceView {
     static int    last_execution_line;
     static string last_execution_pc;
     static string last_shown_pc;
-    static void _show_execution_position (string file, int line, bool silent);
+    static void _show_execution_position (string file, int line, 
+					  bool silent, bool stopped);
 
     // Last frame position
     static int last_frame_pos;
@@ -516,6 +522,7 @@ private:
     // Glyph locations: X[0] is source, X[1] is code
     static Widget plain_arrows[2];
     static Widget grey_arrows[2];
+    static Widget past_arrows[2];
     static Widget signal_arrows[2];
     static Widget drag_arrows[2];
     static WidgetArray plain_stops[2];
@@ -575,7 +582,10 @@ private:
     static int max_breakpoint_number_seen;
 
     // Return breakpoint number of BP_INFO; 0 if new; -1 if none
-    static int jdb_breakpoint(const string& bp_info);
+    static int breakpoint_number(const string& bp_info);
+
+    // Get numbers of selected breakpoints
+    static void getBreakpointNumbers(IntArray& numbers);
 
 public:
     // Constructor
@@ -620,6 +630,7 @@ public:
 
     // Handle 'frame' information
     static void process_frame           (string& frame_output);
+    static void process_frame           (int frame_nr);
 
     // Handle 'info register' information
     static void process_registers       (string& info_register_output);
@@ -669,10 +680,6 @@ public:
     // Reload current file
     static void reload();
 
-    // Lookup previous/next position
-    static void go_back();
-    static void go_forward();
-
     // Return source cursor position in <source>:<line> format.
     static string line_of_cursor();
 
@@ -698,6 +705,10 @@ public:
     static bool register_required();
     static bool thread_required();
 
+    // Check whether we can go up or down
+    static bool can_go_up();
+    static bool can_go_down();
+
     // Check whether source files and code are to be cached
     static bool cache_source_files;
     static bool cache_machine_code;
@@ -733,6 +744,7 @@ public:
     static int source_indent_amount;         // Source
     static int code_indent_amount;           // Machine code
     static int line_indent_amount;           // Extra columns for line numbers
+    static int script_indent_amount;         // Minimum for scripts
 
     // The scrolling amounts
     static int lines_above_cursor;           // Lines to keep before cursor
@@ -828,6 +840,9 @@ public:
     // Return current class path
     static string class_path() { return current_class_path; }
 
+    // Return current source file name
+    static string name_of_source() { return current_source_name(); }
+
     // Return source text and machine code widget (read-only)
     static Widget source() { return source_text_w; }
     static Widget code()   { return code_text_w; }
@@ -839,7 +854,6 @@ public:
     // Clear caches
     static void clear_file_cache();
     static void clear_code_cache();
-    static void clear_history();
 
     // Get the line at POSITION
     static string get_line(string position);
@@ -905,6 +919,13 @@ public:
 
     // Update glyphs for widget W (0: all)
     static void update_glyphs(Widget w = 0);
+
+    // Goto history entry
+    static void goto_entry(const string& file, int line,
+			   const string& address, bool exec_pos);
+
+    // Set or unset showing earlier state
+    static void showing_earlier_state(bool set);
 };
 
 inline void SourceView::create_bp(const string& a, Widget w)
