@@ -1,4 +1,4 @@
-// $Id: acconfig.h.in,v 1.33 1998/06/04 17:31:45 zeller Exp $ -*- C++ -*-
+// $Id: acconfig.h.in,v 1.39 1998/11/26 12:30:48 zeller Exp $ -*- C++ -*-
 // General configuration file.
 
 // Copyright (C) 1995-1998 Technische Universitaet Braunschweig, Germany.
@@ -52,12 +52,21 @@
 /* Define if your C++ compiler supports bool types. */
 #undef HAVE_BOOL
 
+/* Define if your C++ compiler supports the mutable keyword. */
+#undef HAVE_MUTABLE
+
+/* Define if your C++ compiler supports the explicit keyword. */
+#undef HAVE_EXPLICIT
+
 /* Define if your C++ compiler supports exception handling. */
 #undef HAVE_EXCEPTIONS
 
 /* Define if your C++ compiler supports ISO C++ standard exceptions. */
 #undef HAVE_STD_EXCEPTIONS
 
+/* Define if your C++ compiler supports namespaces. */
+#undef HAVE_NAMESPACE
+
 /* Define if your C++ compiler supports run-time type information. */
 #undef HAVE_TYPEINFO
 
@@ -113,6 +122,10 @@
 /* Define if the regex_t type has a re_nsub member, according to POSIX.2 */
 #undef HAVE_REGEX_T_RE_NSUB
 
+/* Define if ostrstream::pcount() is increased by 1 after accessing the
+   string via ostrstream::str(), as in the SGI C++ I/O library. */
+#undef OSTRSTREAM_PCOUNT_BROKEN
+
 /* Define to the signal handler type accepted by signal(). 
    See the signal man page and the decl in <signal.h> for the exact type.
    Typically values are int, ..., and int .... */
@@ -150,12 +163,18 @@
 
 // @BOTTOM@
 
+/* Define if _getpty is declared in unistd.h. */
+#undef HAVE__GETPTY_DECL
+
 /* Define if alloca is declared in alloca.h stdlib.h. */
 #undef HAVE_ALLOCA_DECL
 
 /* Define if asctime is declared in time.h. */
 #undef HAVE_ASCTIME_DECL
 
+/* Define if clock is declared in time.h. */
+#undef HAVE_CLOCK_DECL
+
 /* Define if difftime is declared in time.h. */
 #undef HAVE_DIFFTIME_DECL
 
@@ -171,29 +190,23 @@
 /* Define if ftime is declared in sys/timeb.h. */
 #undef HAVE_FTIME_DECL
 
-/* Define if gethostname is declared in unistd.h. */
-#undef HAVE_GETHOSTNAME_DECL
-
 /* Define if gethostbyname is declared in netdb.h. */
 #undef HAVE_GETHOSTBYNAME_DECL
 
-/* Define if getrusage is declared in sys/resource.h. */
-#undef HAVE_GETRUSAGE_DECL
-
-/* Define if getrlimit is declared in sys/resource.h. */
-#undef HAVE_GETRLIMIT_DECL
-
-/* Define if setrlimit is declared in sys/resource.h. */
-#undef HAVE_SETRLIMIT_DECL
-
-/* Define if getwd is declared in unistd.h. */
-#undef HAVE_GETWD_DECL
+/* Define if gethostname is declared in unistd.h. */
+#undef HAVE_GETHOSTNAME_DECL
 
 /* Define if getpty is declared in unistd.h. */
 #undef HAVE_GETPTY_DECL
 
-/* Define if _getpty is declared in unistd.h. */
-#undef HAVE__GETPTY_DECL
+/* Define if getrlimit is declared in sys/resource.h. */
+#undef HAVE_GETRLIMIT_DECL
+
+/* Define if getrusage is declared in sys/resource.h. */
+#undef HAVE_GETRUSAGE_DECL
+
+/* Define if getwd is declared in unistd.h. */
+#undef HAVE_GETWD_DECL
 
 /* Define if grantpt is declared in stdlib.h. */
 #undef HAVE_GRANTPT_DECL
@@ -201,7 +214,7 @@
 /* Define if hypot is declared in math.h. */
 #undef HAVE_HYPOT_DECL
 
-/* Define if ioctl is declared in unistd.h. */
+/* Define if ioctl is declared in unistd.h sys/ioctl.h. */
 #undef HAVE_IOCTL_DECL
 
 /* Define if link is declared in unistd.h. */
@@ -219,12 +232,12 @@
 /* Define if memset is declared in string.h. */
 #undef HAVE_MEMSET_DECL
 
-/* Define if popen is declared in stdio.h. */
-#undef HAVE_POPEN_DECL
-
 /* Define if pclose is declared in stdio.h. */
 #undef HAVE_PCLOSE_DECL
 
+/* Define if popen is declared in stdio.h. */
+#undef HAVE_POPEN_DECL
+
 /* Define if ptrace is declared in unistd.h sys/ptrace.h. */
 #undef HAVE_PTRACE_DECL
 
@@ -246,18 +259,21 @@
 /* Define if setbuf is declared in stdio.h. */
 #undef HAVE_SETBUF_DECL
 
+/* Define if setpgid is declared in unistd.h. */
+#undef HAVE_SETPGID_DECL
+
 /* Define if setpgrp is declared in unistd.h. */
 #undef HAVE_SETPGRP_DECL
 
 /* Define if setpgrp2 is declared in unistd.h. */
 #undef HAVE_SETPGRP2_DECL
 
-/* Define if setpgid is declared in unistd.h. */
-#undef HAVE_SETPGID_DECL
-
 /* Define if setpwent is declared in pwd.h. */
 #undef HAVE_SETPWENT_DECL
 
+/* Define if setrlimit is declared in sys/resource.h. */
+#undef HAVE_SETRLIMIT_DECL
+
 /* Define if setsid is declared in unistd.h. */
 #undef HAVE_SETSID_DECL
 
@@ -267,12 +283,12 @@
 /* Define if sigblock is declared in signal.h. */
 #undef HAVE_SIGBLOCK_DECL
 
-/* Define if sigsetmask is declared in signal.h. */
-#undef HAVE_SIGSETMASK_DECL
-
 /* Define if sigprocmask is declared in signal.h. */
 #undef HAVE_SIGPROCMASK_DECL
 
+/* Define if sigsetmask is declared in signal.h. */
+#undef HAVE_SIGSETMASK_DECL
+
 /* Define if sigsuspend is declared in signal.h. */
 #undef HAVE_SIGSUSPEND_DECL
 
@@ -294,26 +310,41 @@
 /* Define if strsignal is declared in string.h. */
 #undef HAVE_STRSIGNAL_DECL
 
+/* Define if strtod is declared in stdlib.h. */
+#undef HAVE_STRTOD_DECL
+
 /* Define if strtol is declared in stdlib.h. */
 #undef HAVE_STRTOL_DECL
 
-/* Define if strtod is declared in stdlib.h. */
-#undef HAVE_STRTOD_DECL
+/* Define if strtoul is declared in stdlib.h. */
+#undef HAVE_STRTOUL_DECL
 
 /* Define if symlink is declared in unistd.h. */
 #undef HAVE_SYMLINK_DECL
 
+/* Define if tcdrain is declared in termios.h. */
+#undef HAVE_TCDRAIN_DECL
+
+/* Define if tcflow is declared in termios.h. */
+#undef HAVE_TCFLOW_DECL
+
+/* Define if tcflush is declared in termios.h. */
+#undef HAVE_TCFLUSH_DECL
+
 /* Define if tcgetattr is declared in termios.h. */
 #undef HAVE_TCGETATTR_DECL
 
-/* Define if tcsetattr is declared in termios.h. */
-#undef HAVE_TCSETATTR_DECL
+/* Define if tcgetpgrp is declared in unistd.h. */
+#undef HAVE_TCGETPGRP_DECL
 
 /* Define if tcgetsid is declared in sys/termios.h. */
 #undef HAVE_TCGETSID_DECL
 
-/* Define if tcgetpgrp is declared in unistd.h. */
-#undef HAVE_TCGETPGRP_DECL
+/* Define if tcsendbreak is declared in termios.h. */
+#undef HAVE_TCSENDBREAK_DECL
+
+/* Define if tcsetattr is declared in termios.h. */
+#undef HAVE_TCSETATTR_DECL
 
 /* Define if tcsetpgrp is declared in unistd.h. */
 #undef HAVE_TCSETPGRP_DECL
