@@ -1,4 +1,4 @@
-// $Id: disp-read.h,v 1.30 1998/06/09 15:55:23 zeller Exp $
+// $Id: disp-read.h,v 1.34 1998/10/23 21:14:15 zeller Exp $
 // Helper functions to process GDB display output
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -75,6 +75,9 @@ bool is_pc_cmd(const string& cmd);
 // True if CMD starts debuggee
 bool is_run_cmd(const string& cmd);
 
+// True if CMD kills debuggee
+bool is_kill_cmd(const string& cmd);
+
 // True if CMD sets debuggee arguments.
 bool is_set_args_cmd(const string& cmd);
 
@@ -90,7 +93,7 @@ bool is_core_cmd(const string& cmd);
 bool is_thread_cmd(const string& cmd);
 
 // True if CMD changes variable values.
-bool is_set_cmd(const string& cmd, GDBAgent *gdb);
+bool is_assign_cmd(const string& cmd, GDBAgent *gdb);
 
 // True if CMD changes debugger settings.
 bool is_setting_cmd(const string& cmd);
@@ -131,6 +134,9 @@ bool is_graph_cmd(const string& cmd);
 // True if CMD is an internal `graph refresh' command.
 bool is_refresh_cmd(const string& cmd);
 
+// True if CMD is a `print' command.
+bool is_print_cmd(const string& cmd, GDBAgent *gdb);
+
 // True if CMD is some other builtin (not user-defined) command.
 bool is_other_builtin_cmd(const string& cmd, GDBAgent *gdb);
 
@@ -140,6 +146,9 @@ string get_display_expression(const string& cmd);
 // Return the string after a `break' command
 string get_break_expression(const string& cmd);
 
+// Return the variable in an assignment command
+string get_assign_variable(const string& cmd);
+
 // True if ARG has the form `FILE:LINE'
 bool is_file_pos(const string& arg);
 
@@ -199,8 +208,8 @@ string  read_disp_name   (string& display, GDBAgent *gdb);
 // True if some display has been disabled
 bool is_disabling (const string& value, GDBAgent *gdb);
 
-// True if VALUE is an invalid value (i.e., an error message)
-bool is_invalid(const string& value);
+// True if VALUE is an valid value (i.e., not an error message)
+bool is_valid(const string& value, GDBAgent *gdb);
 
 
 
