@@ -1,4 +1,4 @@
-// $Id: print.h,v 1.5 1998/03/25 12:46:19 zeller Exp $ -*- C++ -*-
+// $Id: print.h,v 1.6 1998/10/01 19:14:30 zeller Exp $ -*- C++ -*-
 //
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -35,8 +35,9 @@
 
 #include "ddd.h"
 
-extern void graphQuickPrintCB (Widget, XtPointer, XtPointer);
-extern void graphPrintCB      (Widget, XtPointer, XtPointer);
+extern void PrintGraphCB (Widget, XtPointer, XtPointer);
+extern void PrintPlotCB  (Widget, XtPointer, XtPointer);
+extern void PrintAgainCB (Widget, XtPointer, XtPointer);
 
 #endif // _DDD_print_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
