@@ -1,5 +1,5 @@
 // This file was modified for -*- C++ -*-
-// using $RCSfile: yacctoC.h,v $ $Revision: 1.6 $
+// using $RCSfile: yacctoC.h,v $ $Revision: 1.7 $
 
 typedef struct _IGNORED_YYSTYPE  {
     // Our special yacctoC program makes this a struct -- 
@@ -53,4 +53,4 @@ typedef struct _IGNORED_YYSTYPE  {
 #define	THREEDOTS	287
 
 
-extern IGNORED_YYSTYPE IGNORED_yylval;
+extern IGNORED_YYSTYPE IGNORED_vsllval;
